==> haskell-clientsession-0.9.1.2-323-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.1.2
visibility:           public
id:                   clientsession-0.9.1.2-COqHnajN18K27dCuNyOg3M
key:                  clientsession-0.9.1.2-COqHnajN18K27dCuNyOg3M
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  3289bd3f97082f8034159d60a91256f7
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.0.2/site-local/clientsession-0.9.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clientsession-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.1.2-COqHnajN18K27dCuNyOg3M
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-iG6YBGhLkRJagBsFqRAI2
    bytestring-0.10.12.1 cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    cipher-aes-0.2.11-8RHtOtsjaCIGoAMR9vOsES
    cprng-aes-0.6.1-Bqk8cQmK8COCTFEqiuhpiy
    crypto-api-0.13.3-H2rQjLwJg166An3m7THxYG
    crypto-random-0.0.9-7gQFhjJtH6ZCfBMBOrJKfm directory-1.3.6.2
    entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk
    setenv-0.1.1.3-KTYV4DvUbeGDVcVTxisS4U
    skein-1.0.9.4-7F7bFOKYkZV3IasdubDog9
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.2.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.2.0
visibility:           public
id:                   clientsession-0.9.2.0-INKYue0Z5jEIvlktBbTYC0
key:                  clientsession-0.9.2.0-INKYue0Z5jEIvlktBbTYC0
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  4b03619a96d0dff1bfdae06ef5a2581b
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.0.2/site-local/clientsession-0.9.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clientsession-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.2.0-INKYue0Z5jEIvlktBbTYC0
depends:
    base-4.15.1.0 base64-bytestring-1.2.1.0-D7qbdpqh7ZAHvyipCqb2En
    bytestring-0.10.12.1 cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-EHPdhbKdFzpJPwJ37IaBSu
    cryptonite-0.30-A2WcUXrCplbraDFo3HWcX directory-1.3.6.2
    entropy-0.4.1.10-CwQzC5Ky39pHQuKDZJMypk
    setenv-0.1.1.3-KTYV4DvUbeGDVcVTxisS4U
    skein-1.0.9.4-90mm8PFfaVvFwaUNY79CCJ
    tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
